<?php
class cmsWysiwygIredactor {

    private static $redactor_loaded = false;

	public function displayEditor($field_id, $content = '', $config = array()){

        $this->loadRedactor($config);

        $dom_id = str_replace(array('[',']'), array('_', ''), $field_id);

        echo html_textarea($field_id, $content, array('id' => $dom_id, 'class' => 'imperavi_redactor'));

	}

    private function loadRedactor($config = array()) {

        if(self::$redactor_loaded){ return false; }

        $lang = cmsCore::getLanguageName();

        $template = cmsTemplate::getInstance();
        $user = cmsUser::getInstance();
        $core = cmsCore::getInstance();

        $template->addJSFromContext('wysiwyg/iredactor/files/redactor.js');
        $template->addCSSFromContext('wysiwyg/iredactor/files/redactor.css');
        $template->addJSFromContext('templates/default/js/files.js');
		
		$options = cmsCore::getController('iredactor')->options['options'];
		
		$mask = array('html', 'undo', 'redo', 'formatting', 'formalize', 'bold', 'italic', 'deleted',
				'unorderedlist', 'orderedlist',  'outdent', 'indent', 'image', 'video', 'table', 'link', 'spoiler', 'alignment',
				'horizontalrule', 'fontsize', 'fullscreen', 'smiles', 'fontcolor', 'backcolor', 'file', 'typograph');
		
		$permissions = $user->getPermissions($user->groups);
		
		$buttons = array_keys($permissions['iredactor']);
		
		if (in_array('typograph', $buttons)){$template->addCSS("https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css");};
		
		$options['buttons'] = array_intersect($mask, $buttons);

        $options['plugins'] = array(
            'fontsize',
            'fullscreen',
            'smiles',
            'spoiler',
            'fontcolor',
			'typograph',
			'formalize'
        );
		
		$options['plugins'] = array_intersect($options['plugins'], $buttons);

        if($lang !== 'en'){

            $template->addJSFromContext('wysiwyg/iredactor/files/lang/'.$lang.'.js');

            $options['lang'] = $lang;

        }

        $options['smilesUrl'] = href_to('typograph', 'get_smiles');

        if ($user->is_logged) {

            $context = $core->getUriData();
            $upload_params = array();

            if($context['controller']){
                $upload_params['target_controller'] = $context['controller'];
            }

            if($context['action']){
                $upload_params['target_subject'] = $context['action'];
            }

            if(strpos($core->uri, '/add/') === false && !empty($context['params'][0]) && is_numeric($context['params'][0])){
                $upload_params['target_id'] = $context['params'][0];
            }

            $options['imageUpload'] = href_to('iredactor/upload').($upload_params ? '?'.http_build_query($upload_params) : '');

            $options['imageGetJson'] = href_to('redactor/images_list').($upload_params ? '?'.http_build_query($upload_params) : '');
			
			$options['fileUpload'] = href_to('iredactor/uploadfile').($upload_params ? '?'.http_build_query($upload_params) : '');

            if($context['controller'] && $context['action']){
                $options['predefinedLinks'] = href_to('redactor/links_list').($upload_params ? '?'.http_build_query($upload_params) : '');
            }

        }

        $options['minHeight'] = 200;

        $options = array_merge($options, $config);

        foreach($options['plugins'] as $plugin){

            $template->addJSFromContext('wysiwyg/iredactor/files/plugins/'.$plugin.'/'.$plugin.'.js');

        }

        ?>

        <script type="text/javascript">
            $(function(){
                var imperavi_options = <?php echo json_encode($options); ?>;
                icms.files.url_delete = '<?php echo href_to('files', 'delete'); ?>';
                imperavi_options.imageDeleteCallback = function (element){
                    if(confirm('<?php echo LANG_PARSER_IMAGE_DELETE; ?>')){
                        icms.files.deleteByPath($(element).attr('src'));
                    }
                };
                $('.imperavi_redactor').redactor(imperavi_options);
            });
        </script>

       <?php

       self::$redactor_loaded = true;

    }

}
